# solisge

Plugin desenvolvido para realizar integrações entre o SolisGE e o Moodle

## Configurações do Moodle
- **secret**: Chave privada compartilhada entre Moodle e SolisGE para tornar a comunicação segura.
Para gerar a Chave Privada, você pode utilizar o comando:
```
ssh-keygen -t rsa -b 4096 -m PEM -f solisge.key
```
- **salt**: Chave privada utilizada para fazer o checksum das informações recebidas pelo SolisGE. É importante que o salt seja atualizado periódicamente. Deste modo, não há necessidade de atualização da chave privada.
- **crossdomaincheck**: Habilita/desabilita a checagem do domínio de origem da requisição.
- **alloweddomaincheck**: Caminho do SolisGE que está autorizado a fazer requisições para o plugin no moodle. Esta configuração necessita que o crossdoamincheck esteja habilitado.


## Features:
**Autenticação SSO por meio do protocolo JWT**
- SSO Security
- - RSA256 Private Key
- - sha256rsa token (segurança por meio de checksun dos dados recebidos pelo moodle)
- - Crossdomain check (validação da origem das solicitações do solisge)

**Transaction Log (registro de todas as transações realizadas pelo plugin solisge**


## Database:
**mdl_solisge_transactions**
Armazena todas as transações realizadas pelo SolisGE.
- **resource** é a função chamada pelo SolisGE
- **transaction** é a ação realizada por meio da função
- **value** registra as informações relevantes relacionadas à transação
- **datetime** timestamp da data/hora em que a trnasação aconteceu
>     select * from mdl_solisge_transactions;
```
 id | resource | transactions |           value            |  datetime  
----+----------+--------------+----------------------------+------------
 11 | jwt      | authuser     | {"username":"08887042675"} | 1688584867
 13 | jwt      | authuser     | {"username":"solis"}       | 1688585376
```


# API
 * Função que registra as ações realizadas pelo plugin
 * @resource qual foi o recurso do plugin
 * @transaction qual foi a transação 
 * @value valor referente à transação

**function log_transaction($resource, $transaction, $value)**

 * Verifica se o domínio de origem está na lista de autorizados
 * na configuração do solisge
 * @return boolean

**function jwt_crossdomain_check()**

 * Valida as informações recebidas pelo jwt
 * @param $data objeto com as informações recebidas do jwt
 * @return boolean retorna true se as informações são válidas
 * e seguras.
 * OBSERVAÇÃO: esta função é utilizada pela função jwt_get_info para validar
 * a entrada de dados. É obrigatório o recebimento do username e do checksum 
 * em todas as transações com o jwt.

**function jwt_info_validate($data)**

 * Decodifica informações do jwt e retorna os dados recebidos do SolisGE
 * @return boolean|$data

**function jwt_get_info($jwt)**

### como utilizar:
```
require_once '../../config.php';
require_once 'lib.php';

$jwt = required_param('jwt',PARAM_RAW);

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

try {
    $jwtData = jwt_get_info($jwt);

} catch (Exception $e) {
    echo 'Erro: ' . $e->getMessage();
}
```
