<?php


require_once __DIR__.'/../../config.php';
//require_once 'lib.php';

use Firebase\JWT\JWT;
use Firebase\JWT\Key;

/**
 * Função que registra as ações realizadas pelo plugin
 * @resource qual foi o recurso do plugin
 * @transaction qual foi a transação 
 * @value valor referente à transação
 */
function log_transaction($resource, $transaction, $value){
    global $DB;

    $reg = new stdClass();
    $reg->resource = $resource;
    $reg->transactions = $transaction;
    $reg->value = json_encode($value);
    $reg->datetime = time();

    if(!$id = $DB->insert_record('solisge_transactions',$reg)){
        return false;
    }
    return true;
}


/**
 * Valida as informações recebidas pelo jwt
 * @param $data objeto com as informações recebidas do jwt
 * @return boolean retorna true se as informações são válidas
 * e seguras.
 */
function jwt_info_validate($data){
	$salt = get_config('local_solisge','salt');

	//verific se as informações existem
	if(empty($data->username) || empty($data->checksum)){
		return false;
	}	

	//valida checksum
	if($data->checksum !== md5($salt.$data->username)){
		return false;
	}

    //verifica domínio
    if(get_config('local_solisge','alloweddomaincheck') !== ''){
        return jwt_crossdomain_check();
    }
    unset($data->checksum);
	return true;
}

/**
 * Decodifica informações do jwt e retorna os dados recebidos do SolisGE
 * @return boolean|$data
 */
function jwt_get_info($jwt){

    if(empty($jwt)){
        return false;
    }

    $secret = get_config('local_solisge','secret');
    $secret = str_replace(array("\r"), '', $secret);

    try{
        $jwtDecode = JWT::decode($jwt, new Key($secret,'HS256'));
    
    }catch(Exception $e){
	    throw new Exception(get_string('error:jwtdecode','local_solisge',array('message'=>$e->getMessage())));
    }

    if(!jwt_info_validate($jwtDecode->data)){
	    throw new Exception(get_string('error:validationdatafailed','local_solisge'));
    }

    return $jwtDecode->data;
}

/**
 * Verifica se o domínio de origem está na lista de autorizados
 * na configuração do solisge
 * @return boolean
 */
function jwt_crossdomain_check(){
    if(!get_config('local_solisge','crossdomaincheck')){//verifica se a validação de domínio está ativada
        return true;
    }

    $alloweddomain = get_config('local_solisge','alloweddomaincheck');
    if(empty($alloweddomain)){
        //crossdomain habilitado mas não há valor no campo alloweddomaincheck
	    throw new Exception(get_string('error:crossdomainempty','local_solisge'));
    }

    if (isset($_SERVER['HTTP_ORIGIN'])) {
        $origin = $_SERVER['HTTP_ORIGIN'];

        if ($origin === $alloweddomain) {
            return true;
        } else {
            http_response_code(403); // Define o código de status 403 (Acesso Negado)
            throw new Exception(get_string('error:crossdomainforbiden','local_solisge'));
        }
    } else {
        http_response_code(403); // Define o código de status 403 (Acesso Negado)
        throw new Exception(get_string('error:crossdomainforbiden','local_solisge'));
    }
}
